@@ -1,7 +1,9 @@
 from logging import getLogger, Formatter, DEBUG, WARNING, StreamHandler
 
+from pysecure.config import IS_DEVELOPMENT
+
 default_logger = getLogger()
-default_logger.setLevel(WARNING)
+default_logger.setLevel(DEBUG if IS_DEVELOPMENT else WARNING)
 
 log_console = StreamHandler()
 log_format = '%(name)-12s %(levelname)-7s %(message)s'
